"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internals_1 = require("../internals");
/**
 * Creates an empty tree. If no ComparatorFn function is supplied, keys are compared using logical less-than and
 * greater-than operations, which will generally only be suitable for numeric or string keys.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {ComparatorFn<K>} compare A comparison function, taking two keys, and returning a value less than 0 if the
 *                                  first key is smaller than the second, a value greater than 0 if the first key is
 *                                  greater than the second, or 0 if they're the same.
 * @param {boolean} [mutability] Indicates the desired mutability of the returned tree
 * @returns {RedBlackTreeStructure<K, V>} An empty tree
 */
function empty(compare, mutability) {
    return internals_1.createTree(compare, mutability);
}
exports.empty = empty;
//# sourceMappingURL=empty.js.map