"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@collectable/core");
const iterateFromFirst_1 = require("./iterateFromFirst");
const size_1 = require("./size");
/**
 * Determines whether two trees have equivalent sets of keys and values. Though order of insertion can affect the
 * internal structure of a red black tree, only the actual set of entries and their ordinal positions are considered.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The input tree
 * @param {RedBlackTreeStructure<K, V>} other Another tree to compare entries with
 * @returns {boolean} True if both trees are of the same size and have equivalent sets of keys and values for each entry
 *   at corresponding indices in each tree, otherwise false.
 */
function isEqual(tree, other) {
    if (tree === other)
        return true;
    if (size_1.size(tree) !== size_1.size(other))
        return false;
    // Iterator is required because two trees may have the same set of keys and values but slightly different structures
    var ita = iterateFromFirst_1.iterateFromFirst(tree), itb = iterateFromFirst_1.iterateFromFirst(other);
    do {
        var ca = ita.next();
        var cb = itb.next();
        if (!core_1.isEqual(ca.value, cb.value))
            return false;
    } while (!ca.done);
    return true;
}
exports.isEqual = isEqual;
//# sourceMappingURL=equality.js.map