"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internals_1 = require("../internals");
/**
 * Returns an iterator that starts from the last entry in the tree and iterates toward the start of the tree. Emissions
 * are references to nodes in the tree, exposed directly to allow Collectable.RedBlackTree to be efficiently consumed as
 * a backing structure for other data structures. Do not modify the returned node.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The input tree
 * @returns {RedBlackTreeIterator<K, V>} An iterator for entries in the tree
 */
function iterateFromLast(tree) {
    var path = internals_1.PathNode.NONE;
    var node = tree._root;
    while (!internals_1.isNone(node)) {
        path = internals_1.PathNode.next(node, path, 2 /* RIGHT */);
        node = node._right;
    }
    return internals_1.RedBlackTreeIterator.create(path, tree._compare, true);
}
exports.iterateFromLast = iterateFromLast;
//# sourceMappingURL=iterateFromLast.js.map