"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internals_1 = require("../internals");
const iterateFromFirst_1 = require("./iterateFromFirst");
/**
 * Returns a value iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<V>} An iterable iterator that will visit each value in the tree
 */
function iterateValuesFromFirst(tree) {
    return new internals_1.RedBlackTreeValueIterator(iterateFromFirst_1.iterateFromFirst(tree));
}
exports.iterateValuesFromFirst = iterateValuesFromFirst;
/**
 * Alias for `iterateValuesFromFirst()`.
 *
 * Returns a value iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<V>} An iterable iterator that will visit each value in the tree
 */
function values(tree) {
    return iterateValuesFromFirst(tree);
}
exports.values = values;
//# sourceMappingURL=iterateFromValuesFromFirst.js.map