"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internals_1 = require("../internals");
const iterateFromFirst_1 = require("./iterateFromFirst");
/**
 * Returns a key iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<K>} An iterable iterator that will visit each key in the tree
 */
function iterateKeysFromFirst(tree) {
    return new internals_1.RedBlackTreeKeyIterator(iterateFromFirst_1.iterateFromFirst(tree));
}
exports.iterateKeysFromFirst = iterateKeysFromFirst;
/**
 * Alias for `iterateKeysFromFirst()`.
 *
 * Returns a key iterator; one for each entry in the tree. The iterator is guaranteed to iterate in the same order as
 * the corresponding entries in the tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTreeStructure<K, V>} tree The tree to read values from
 * @returns {IterableIterator<K>} An iterable iterator that will visit each key in the tree
 */
function keys(tree) {
    return iterateKeysFromFirst(tree);
}
exports.keys = keys;
//# sourceMappingURL=iterateKeysFromFirst.js.map