import * as C from '@collectable/core';
import { Associative, ComparatorFn } from '@collectable/core';
import { RedBlackTreeStructure } from '../internals';
/**
 * Creates a new `RedBlackTree` from a plain input object. If no ComparatorFn function is supplied, keys are compared
 * using logical less-than and greater-than operations, which will generally only be suitable for numeric or string keys.
 *
 * @export
 * @template V The type of values in the tree
 * @param {Associative<V>} obj The input object from which to create a new tree
 * @param {ComparatorFn<any>} compare A comparison function, taking two keys, and returning a value less than 0 if the
 *                                      first key is smaller than the second, a value greater than 0 if the first key is
 *                                      greater than the second, or 0 if they're the same.
 * @returns {RedBlackTreeStructure<string, V>} A tree populated with the keys and values of the input object
 */
export declare function fromObject<V>(obj: Associative<V> | V[], mutability?: C.PreferredContext): RedBlackTreeStructure<string, V>;
export declare function fromObject<V>(obj: Associative<V> | V[], compare?: ComparatorFn<string>, mutability?: C.PreferredContext): RedBlackTreeStructure<string, V>;
